@@ -1,7 +1,6 @@
 from django.core.cache import caches
 from rest_framework.exceptions import PermissionDenied
 
-from sharepoint_rest_api import config
 from sharepoint_rest_api.client import SharePointClient, SharePointClientException
 from sharepoint_rest_api.models import SharePointLibrary
 from sharepoint_rest_api.serializers.sharepoint import SharePointUrlSerializer
@@ -56,8 +55,7 @@ class UrlBasedSharePointViewSet(AbstractSharePointViewSet):
                 dl_info['password'] = dl.site.tenant.password
             try:
                 client = SharePointClient(**dl_info)
-                if config.SHAREPOINT_CACHE_DISABLED:
-                    cache.set(key, client)
+                cache.set(key, client)
             except SharePointClientException:
                 raise PermissionDenied
 
